
Installation
============

The easiest way to install this package is via PyPI:

.. code:: bash

    pip install astromorphlib

If you prefer a manual installation, you can clone the
lastest version at `Gitlab repository <https://https://gitlab.com/joseaher/astromorphlib>`_:

.. code:: bash

    git clone https://gitlab.com/joseaher/astromorphlib.git

After the package download, go into folder:

.. code:: bash

    pip install .


Requirements
=============

Astromorphlib requires the following pacakge to run:

    * statmorph
    * splusdata
    * astro-datalab
    * astroplotlib
    * numpy
    * scipy
    * matplotlib
    * astropy
    * astroquery
    * wget


Uninstallation
=============

In order to uninstall astromorphlib just type on the terminal:

.. code:: bash

   pip uninstall astromorphlib
